#
# spec file for package os-autoinst
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           os-autoinst
Version:        4.6.1589880721.55a008dd
Release:        lp152.1.13
Summary:        OS-level test automation
License:        GPL-2.0-or-later
Group:          Development/Tools/Other
URL:            https://github.com/os-autoinst/os-autoinst
Source0:        %{name}-%{version}.tar.xz
%{perl_requires}
%if 0%{?suse_version} > 1500
# openSUSE Tumbleweed
%define opencv_require pkgconfig(opencv4)
%else
%define opencv_require pkgconfig(opencv)
%endif
%define build_requires %opencv_require autoconf automake gcc-c++ libtool make perl(Module::CPANfile) pkg-config pkgconfig(fftw3) pkgconfig(libpng) pkgconfig(sndfile) pkgconfig(theoraenc)
%define requires perl(B::Deparse) perl(Carp::Always) perl(Class::Accessor::Fast) perl(Cpanel::JSON::XS) perl(Crypt::DES) perl(Data::Dumper) perl(Exception::Class) perl(File::Touch) perl(File::Which) perl(IO::Scalar) perl(IO::Socket::INET) perl(IPC::Run::Debug) perl(IPC::System::Simple) perl(List::MoreUtils) perl(Mojolicious) >= 7.92 perl(Mojo::IOLoop::ReadWriteProcess) >= 0.23 perl(Net::DBus) perl(Net::IP) perl(Net::SNMP) perl(Net::SSH2) perl(Socket::MsgHdr) perl(Term::ANSIColor) perl(Try::Tiny) perl(XML::LibXML) perl(XML::SemanticDiff) perl(autodie) perl-base
%define requires_not_needed_in_tests git-core
# all requirements needed by the tests, do not require on this in the package
# itself or any sub-packages
# SLE is missing spell check requirements
%if !0%{?is_opensuse}
%bcond_with spellcheck
%else
%bcond_without spellcheck
%endif
%if %{with spellcheck}
%define spellcheck_requires perl(Pod::Spell) aspell-spell aspell-en
%define make_check_args %{nil}
%else
%define spellcheck_requires %{nil}
%define make_check_args CHECK_DOC=0
%endif
%define test_requires %build_requires %requires %spellcheck_requires perl(Devel::Cover) perl(Perl::Tidy) perl(Pod::Coverage) perl(Test::Exception) perl(Test::Fatal) perl(Test::MockModule) perl(Test::MockObject) perl(Test::Mock::Time) perl(Test::Output) perl(Test::Pod) perl(Test::Strict) perl(Test::Warnings) qemu-tools
%define devel_requires %test_requires %requires_not_needed_in_tests
BuildRequires:  %test_requires
Requires:       %requires
Requires:       %requires_not_needed_in_tests
Recommends:     tesseract-ocr
Recommends:     /usr/bin/xkbcomp /usr/bin/Xvnc dumponlyconsole
Recommends:     qemu >= 2.0.0
Recommends:     /usr/bin/qemu-img
Requires(pre):  %{_bindir}/getent
Requires(pre):  %{_sbindir}/useradd
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The OS-autoinst project aims at providing a means to run fully
automated tests. Especially to run tests of basic and low-level
operating system components such as bootloader, kernel, installer
and upgrade, which can not easily and safely be tested with other
automated testing frameworks. However, it can just as well be used
to test firefox and openoffice operation on top of a newly
installed OS.

%package devel
Summary:        Development package pulling in all build+test dependencies
Group:          Development/Tools/Other
Requires:       %devel_requires

%description devel
Development package pulling in all build+test dependencies.

%package openvswitch
Summary:        Openvswitch support for os-autoinst
Group:          Development/Tools/Other
Requires:       openvswitch
Requires:       openvswitch-switch
Requires:       os-autoinst

%description openvswitch
This package contains openvswitch support for os-autoinst.

%prep
%setup -q
sed -e 's,/bin/env python,/bin/python3,' -i crop.py
# Replace version number from git to what's reported by the package
sed  -i 's/ my $thisversion = qx{git.*rev-parse HEAD}.*;/ my $thisversion = "%{version}";/' isotovideo

# don't require qemu within OBS
# and exclude known flaky tests in OBS check
# https://progress.opensuse.org/issues/52652
# 07-commands: https://progress.opensuse.org/issues/60755
for i in 07-commands 13-osutils 14-isotovideo 18-qemu-options 18-backend-qemu 99-full-stack; do
    rm t/$i.t
    sed -i "s/ \?$i\.t//g" Makefile.am
done

%build
mkdir -p m4
autoreconf -f -i
%configure --docdir=%{_docdir}/%{name}
make INSTALLDIRS=vendor %{?_smp_mflags}

%install
%make_install INSTALLDIRS=vendor
# only internal stuff
rm %{buildroot}/usr/lib/os-autoinst/tools/{tidy,check_coverage,absolutize,docker_run_ci}
rm -r %{buildroot}/usr/lib/os-autoinst/tools/lib/perlcritic
#
ls -lR %buildroot
find %{buildroot} -type f -name .packlist -print0 | xargs -0 --no-run-if-empty rm -f
find %{buildroot} -depth -type d -and -not -name distri -print0 | xargs -0 --no-run-if-empty rmdir 2>/dev/null || true
%perl_gen_filelist
#
# service symlink
mkdir -p %{buildroot}%{_sbindir}
ln -s ../sbin/service %{buildroot}%{_sbindir}/rcos-autoinst-openvswitch
#
# we need the stale symlinks to point to git
export NO_BRP_STALE_LINK_ERROR=yes

%check
# disable code quality checks - not worth the time for package builds
sed '/perlcritic/d' -i Makefile
sed '/Perl::Critic/d' -i cpanfile
sed '/tidy/d' -i Makefile
rm tools/lib/perlcritic/Perl/Critic/Policy/*.pm

# should work offline
for p in $(cpanfile-dump); do rpm -q --whatprovides "perl($p)"; done
make check test VERBOSE=1 %{make_check_args}

%pre openvswitch
%service_add_pre os-autoinst-openvswitch.service

%post openvswitch
%service_add_post os-autoinst-openvswitch.service

%preun openvswitch
%service_del_preun os-autoinst-openvswitch.service

%postun openvswitch
%service_del_postun os-autoinst-openvswitch.service

%files -f %{name}.files
%defattr(-,root,root)
%{_docdir}/os-autoinst
%dir %{_libexecdir}/os-autoinst
%{_libexecdir}/os-autoinst/videoencoder
%{_libexecdir}/os-autoinst/basetest.pm
#
%{_libexecdir}/os-autoinst/dmidata
#
%{_libexecdir}/os-autoinst/bmwqemu.pm
%{_libexecdir}/os-autoinst/commands.pm
%{_libexecdir}/os-autoinst/distribution.pm
%{_libexecdir}/os-autoinst/testapi.pm
%{_libexecdir}/os-autoinst/mmapi.pm
%{_libexecdir}/os-autoinst/lockapi.pm
%{_libexecdir}/os-autoinst/cv.pm
%{_libexecdir}/os-autoinst/ocr.pm
%{_libexecdir}/os-autoinst/needle.pm
%{_libexecdir}/os-autoinst/osutils.pm
%{_libexecdir}/os-autoinst/myjsonrpc.pm
%{_libexecdir}/os-autoinst/backend
%{_libexecdir}/os-autoinst/OpenQA
%{_libexecdir}/os-autoinst/consoles
%dir %{_libexecdir}/os-autoinst/tools
%{_libexecdir}/os-autoinst/tools/preparepool
%{_libexecdir}/os-autoinst/autotest.pm
%{_libexecdir}/os-autoinst/crop.py

%files openvswitch
%defattr(-,root,root)
%{_libexecdir}/os-autoinst/os-autoinst-openvswitch
/usr/lib/systemd/system/os-autoinst-openvswitch.service
%config /etc/dbus-1/system.d/org.opensuse.os_autoinst.switch.conf
%{_sbindir}/rcos-autoinst-openvswitch

%files devel

%changelog
* Tue May 19 2020 okurz@suse.com
- Update to version 4.6.1589880721.55a008dd:
  * Test error handling of loading test schedule
  * Improve tests for running a test
  * Distinguish errors when loading tests from other errors of os-autoinst
  * Start command server after loading tests
  * Move `serialize_state` to bmwqemu to use it not only within the backend
  * Add conditional skipping of IPMI selftests
* Sun May 17 2020 okurz@suse.com
- Update to version 4.6.1589560350.f30cc856:
  * t: Import stderr_from
  * Use colors in all log calls if colors are available
  * t: Simplify 15-logging.t with Test::Output
  * Reduce code duplication in bmwqemu::init_logger
  * Simplify logger init in bmwqemu
  * Slightly simplify backends ipmi+svirt
  * t: Delete obsolete comment in 20-openqa-benchmark-stopwatch-utils.t
  * Delete unused imports
  * Fix sporadic failures in t/17-basetest.t
  * Fix sporadic failures in t/17-basetest.t
  * Write backend termination message to base_state.json
  * Move Dockerfile for CI testing from openQA repo
  * Add retries for 'qemu-img create' commands which fail sometimes for unknown reason
* Thu May 14 2020 okurz@suse.com
- Update to version 4.6.1589459603.638a25e2:
  * Remove status API call
  * spec: Remove tools/docker_run_ci from installed tools
  * Sort imports in t/14-isotovideo.t
  * Define travis CI command in simple helper script
* Sun May 10 2020 okurz@suse.com
- Update to version 4.6.1588950686.b8a0ab33:
  * Replace all uses of mock with redefine
* Thu May  7 2020 okurz@suse.com
- Update to version 4.6.1588792901.b77cfa03:
  * backend: Simplify power method in qemu
  * Fix qemu power action 'acpi'
  * Simplify backend::qemu::can_handle with early returns
  * Ensure 'rundcmd' output is shown with error
* Tue May  5 2020 okurz@suse.com
- Update to version 4.6.1588626699.4bac4dc6:
  * Add optional fatal handling for qemu dbus calls for easier error analysis
* Sun May  3 2020 okurz@suse.com
- Update to version 4.6.1588309862.a289607f:
  * Include command in error message of osutils::runcmd
* Thu Apr 30 2020 okurz@suse.com
- Update to version 4.6.1588239900.85fa4f12:
  * Speedup "integration" full stack tests
  * t: Simplify 'TESTING_ASSERT_SCREEN_TIMEOUT' handling in test code
* Sat Apr 25 2020 okurz@suse.com
- Update to version 4.6.1587738559.30bdb018:
  * Dependencies: Remove Data::Dump, JSON, JSON::XS from spec
  * Create and remove tempfiles in every test
  * Dependencies: sort requires
  * Dependencies: remove commas in spec
* Wed Apr 22 2020 okurz@suse.com
- Update to version 4.6.1587572338.0c00bf0a:
  * Dependencies: sort cpanfile
* Tue Apr 14 2020 okurz@suse.com
- Update to version 4.6.1586871095.50464d4e:
  * script: Ensure no left over .tdy files on aborted/failed tidy
* Sat Apr 11 2020 okurz@suse.com
- Update to version 4.6.1586545507.8e465c4a:
  * Simplify CI tests by relying on upstream openQA development image only
* Thu Apr  9 2020 okurz@suse.com
- Update to version 4.6.1586248053.54525e23:
  * Add execution time in the result file
* Tue Apr  7 2020 okurz@suse.com
- Update to version 4.6.1586199429.5c9b00ed:
  * Update doc for default value of VNC_TYPING_LIMIT
* Sat Apr  4 2020 okurz@suse.com
- Update to version 4.6.1585921232.ea68c7de:
  * Allow TESTS variable to be specified with make test
  * Make point in time when a test fails in log more explicit
  * Remove ConsistentQuoteLikeWords perlcritic policy
  * Further speedup isotovideo shutdown by 1-2s
  * Add trivial 'null' backend, suitable for testing
  * bmwqemu: Fix warning about undefined HDD in _check_publish_vars
* Wed Apr  1 2020 okurz@suse.com
- Update to version 4.6.1585773920.a1e4f68e:
  * Replace ambiguous special word "FIXME" in template strings
  * Delete obsolete FIXME comments
  * Delete unused "get_ocr" method
  * Harmonize License copyright format
  * Prevent "malformed JSON" on qemu-img failure also with custom die handler
* Thu Mar 26 2020 okurz@suse.com
- Update to version 4.6.1585251444.36bb1cf8:
  * Fix missing checkout from git on single commit
  * Avoid misleading error message from qemu-img
  * Revert "Check exit code when running qemu-img"
  * Check exit code when running qemu-img
* Sat Mar 21 2020 okurz@suse.com
- Update to version 4.6.1584822453.7eb772a7:
  * Add support for cloning and checking out a single git commit through CASEDIR
  * Simplify automatic coverage analysis with just statement coverage
* Wed Mar 11 2020 okurz@suse.com
- Update to version 4.6.1583960405.4e3dec50:
  * Add power function to spvm backend
  * Fix git hash not being able to compute when no git is available
  * Switch to a hash for args of generalhw commands
  * Add optional args to GENERAL_HW_POWERON_CMD and GENERAL_HW_POWEROFF_CMD
  * Add support to checkout git refspec in existing working copies
* Fri Mar  6 2020 okurz@suse.com
- Update to version 4.6.1583493337.35921fbf:
  * Fix serialdev configuration for pvm_hmc poo#64105
* Fri Feb 28 2020 okurz@suse.com
- Update to version 4.6.1582730128.1997f880:
  * Append HDD infos to GENERAL_HW_FLASH_ARGS - poo#63766
  * Improve bwmqemu::log_call
* Wed Feb 26 2020 okurz@suse.com
- Update to version 4.6.1582561187.791d0a5d:
  * Revert "Show the execution time of job modules"
* Mon Feb 24 2020 okurz@suse.com
- Update to version 4.6.1582484281.39523e82:
  * generalhw: Allow GENERAL_HW_SOL_CMD to get args with GENERAL_HW_SOL_ARGS
* Fri Feb 21 2020 okurz@suse.com
- Update to version 4.6.1582291474.ac30363e:
  * Add test for shutdown time of complete stack
  * Show the execution time of job modules
* Fri Feb 21 2020 okurz@suse.com
- Update to version 4.6.1582204744.809d37e7:
  * ipmi: Check for all required variables instead of confusing stack traces
* Tue Feb 18 2020 okurz@suse.com
- Update to version 4.6.1582007909.a256d580:
  * Improve log output of test module as well as lib function lines
  * t: Cut 18-qemu-options.t runtime from 45s to 27s by allowing to abort qemu start early
* Sun Feb  9 2020 okurz@suse.com
- Update to version 4.6.1581101005.a5c3ec95:
  * t: Catch all output in 01-test_needle.t
  * t: Catch all output in 02-test_ocr.t
  * Extract "init_logger" function for easier output grabbing in tests
* Fri Feb  7 2020 okurz@suse.com
- Update to version 4.6.1580905395.63af2f4f:
  * virtio_console: Fix `no autodie` placement for fcntl(PIPE_SZ)
  * Add "assert_still_screen" test API function
* Mon Feb  3 2020 okurz@suse.com
- Update to version 4.6.1580718127.98503bd5:
  * virtio_terminal: Add test for virtio_terminal::open_pipe()
  * virtio_terminal: Don't force max PIPE_SZ
* Fri Jan 31 2020 okurz@suse.com
- Update to version 4.6.1580337089.6f2b5c86:
  * t: Cut 18-qemu-options.t runtime from 135s to 45s by configuring attempt interval
  * Allow to configure no drives for drive-less systems
* Wed Jan 29 2020 okurz@suse.com
- Update to version 4.6.1580119736.fd9ea32d:
  * Ignore t/vars.json created by local tests
  * t: Remove redundant comment in 08-autotest for subtest
  * Cleanup old content in autogen.sh
* Fri Jan 24 2020 okurz@suse.com
- Update to version 4.6.1579872857.bb06065a:
  * Update tidy to 20200110
* Mon Jan 20 2020 okurz@suse.com
- Update to version 4.6.1579522398.2afcda12:
  * qemu: handle armv6/7 architectures properly
  * qemu: allow to use different soundhw option with QEMU_SOUNDHW
* Tue Jan 14 2020 okurz@suse.com
- Update to version 4.6.1578910353.e34101c6:
  * qemu: Allow to configure maximum file migration time
  * Fix condition for using pkgconfig(opencv4)
* Sat Jan 11 2020 okurz@suse.com
- Update to version 4.6.1578638802.5822dfa3:
  * qemu: Check expected format for snapshotted image
* Wed Jan  8 2020 okurz@suse.com
- Update to version 4.6.1578494926.ba218583:
  * Ensure tianocore boot menu is shown for aarch64 workaround
* Thu Dec 26 2019 okurz@suse.com
- Update to version 4.6.1577344452.d693abe0:
  * Fix default boot menu timeout in qemu backend (#1332)
* Fri Dec 20 2019 okurz@suse.com
- Update to version 4.6.1576848145.65c8fecf:
  * Fix the warning message in t/17-basetest.t
  * Avoid qw() warning message in t/18-qemu.t
  * Add .gitignore files for make test output
  * Use getter/setter for needles dir as safer approach rather than package variable
* Mon Dec 16 2019 okurz@suse.com
- Update to version 4.6.1576491023.ca931ae6:
  * testapi: Fix comment about default mouse click hold time
* Sat Dec 14 2019 okurz@suse.com
- Update to version 4.6.1576248007.5d938a10:
  * Update to new perltidy version 20191203
  * Fix undefined needles dir in dynamic needle downloader with proper variable names
  * Escape parameters in log calls
* Wed Dec 11 2019 okurz@suse.com
- Update to version 4.6.1576050328.08c055a7:
  * Add powerVM over HMC backend
  * Remove "use Devel::Cover" from 07-commands.t
  * t/22-svirt.t: add open_serial_console_via_ssh test
  * Makefile: Check for spellcheck requirements
  * sshXtermVt: check for SSH port available instead of a simple ping to check host availability
  * svirt: open_serial_console_via_ssh - doc and cleanup
  * Add new test/cover targets and run tests with prove
  * Fix warning on failed load_snapshot command
  * backend_vars: Add infos for generalhw ssh/noVNC and flash cmd
  * generalhw: allow to use real serial with ssh/noVNC mode
  * sshXtermVt: wait that SUT is alive on network before starting ssh in xterm Use SSH_XTERM_WAIT_SUT_ALIVE_TIMEOUT to adjust wait time, default 120 s
  * generalhw: Add flash command support and handle optionnal args for cmd
  * generalhw: Enable SSH access when VNC is not selected
  * generalhw: truncate serial file on start
* Mon Dec  9 2019 okurz@suse.com
- Update to version 4.6.1575895968.5daf6345:
  * t/23-baseclass.t: Fix read from serial test
  * check_ssh_serial: Fix reading from channel
  * spec: Exclude flaky 07-commands from tests
  * Allow relative "productdir" and "needledir" relative to "casedir"
  * Delete never fully working check for "needle dir within current dir"
  * t: Use Test::Strict like in openQA for an easier and broader 'compile' check
* Sat Dec  7 2019 okurz@suse.com
- Update to version 4.6.1575621538.1ee59881:
  * baseclass.t: Add tests for SSH serial methods
  * Use OpenCV 4 under Tumbleweed
  * Reduce overly long waiting time on shutdown waiting on processes
  * t: Enable 00-compile-check-all.t to be run with prove
  * Add simple test for serial_screen.pm
  * Add simple test for ssh_screen.pm
  * ssh_screen: Fix initialize of base class
  * t: Enable 04-check_vars_docu.t to be run with prove
  * t: Enable 10-terminal.t to be run with prove
* Wed Dec  4 2019 okurz@suse.com
- Update to version 4.6.1575491566.71ee5f56:
  * Adjust select option for Devel::Cover and PERL5LIB
  * Remove @INC modifications from tests
  * Support VNC pseudo encoding 'last rect' (#1310)
  * t: Fix warning in tests about wrong regex for Devel::Cover
  * myjsonrpc: Canonalize condition form
  * myjsonrpc: Fix unclean shutdown introduced in 449baece
  * t: Catch all output in 07-commands.t
  * Print note about reusing old Git checkout
  * SSH serial: Close connection on read error
  * t: Explain better the need for 'use Devel::Cover' in 07-commands.t
* Mon Dec  2 2019 okurz@suse.com
- Update to version 4.6.1575282624.855b4f79:
  * t: Save further time in full stack test
  * Add options to configure SSH console based retries and interval
  * Move %%SIG overrides even closer where needed to allow early termination
  * Fix termination of backend during startup introduced with e90faa18
  * Skip zypper upgrade in CI tests by default as for openQA
* Sat Nov 30 2019 okurz@suse.com
- Update to version 4.6.1575042468.93be69f8:
  * ppmclibs: Fix warning "\1 better written as $1"
  * qemu: Explicit delete named pipes from virtio console
  * qemu: Fix missing data while reading from virtio_console
  * Fix building snd2png with OpenCV 4
  * Remove 'wait_idle' after being deprecated for more than 2 years
  * Make qemu boot menu optional to save 5s in every qemu test run
* Tue Nov 26 2019 okurz@suse.com
- Update to version 4.6.1574795840.3973b078:
  * t: Catch output in 18-backend-qemu.t
  * Remove obsolete AUTO_INST after more than a year past c670720d
  * Prevent duplicate "Saving QEMU state to qemu_state.json"
  * Avoid the word "killing" to have nicer wording and discern it from POSIX "kill"
  * svirt: Wait for logfile from script in open_serial_console_via_ssh
  * backend: Extract 'truncate_serial_file' into base class
  * Delete vim footer in files that still have it
* Fri Nov 22 2019 okurz@suse.com
- Update to version 4.6.1574429927.5158b63b:
  * Allow unsetting 'fatal' test flag without snapshot support
  * Improve waiting for data in myjsonrpc::read_json()
  * Launch debugging tools without shell
  * t: Prevent error in RPM build on empty line after backslash
  * Improve example in documentation for CASEDIR
  * t: Split tests in Makefile for easier diff handling
  * Prevent confusing call stack-trace from send_json on shutdown
  * qemu: Distinguish 'syswrite failed' die message from myjsonrpc one
* Mon Nov 18 2019 okurz@suse.com
- Update to version 4.6.1573902023.b0a2a79e:
  * Hide SSH password in logs
  * Add test for SSH credentials in spvm
  * Add ssh usage tests for baseclass
  * Generalize Net::SSH2 usage in svirt backend
* Sat Nov 16 2019 okurz@suse.com
- Update to version 4.6.1573837019.f65a27bc:
  * spec: Add missing spellcheck requirements
* Wed Nov 13 2019 okurz@suse.com
- Update to version 4.6.1573666306.8fe5e5bd:
  * Increase the read buffer for JSON RPC
  * qemu: Fix MAKETESTSNAPSHOTS with test modules in nested dirs
  * qemu: Fix double '//' in snapshot paths depending on distri value
  * Improve OCR test to avoid default-initialization of needles dir
  * Fix custom needle dir checkouts by removing check for "working directory"
  * Forward select_console failures to test process for proper reporting (#1262)
  * Prevent incompatible overwriting of source qcow images
  * bmwqemu: Delete useless package prefix on variable
  * testapi: Fix spellcheck fail on 'json'
  * Follow VNC_TYPING_LIMIT everywhere (including send_key)
* Sun Nov 10 2019 okurz@suse.com
- Update to version 4.6.1573405893.c5877f02:
  * Get rid of unhelpful log about "unknown process"
  * Adapt tests to needle handling changes
  * Remove use of $bmwqemu::vars{PRJDIR}
  * Initialize $needle::needles_dir within needle::init
  * Use $needle:needles_dir in the needle downloader
  * Assume that the variable not defined in checkout_git_repo_and_branch
* Fri Nov  8 2019 okurz@suse.com
- Update to version 4.6.1573214011.87166a81:
  * Read all available bytes in check_ssh_serial
  * Fix OBS package checks due to qemu unavailability
  * qemu: Add option to activate balloon before snapshot
  * myjsonrpc: Improve debugging
  * Add wait_screen_change option on send_key
  * Add option to upload assets on demand even in failed jobs
  * Implement shutdown check for spvm backend
  * script_output() - Add code comment for commit 72efc09b
  * Allow consoles to persist over reset (#1232)
  * myjsonrpc: Go back to incremental parsing (#1248)
  * Use python3 by default (#1247)
  * Avoid warning in comparison; num_queues might be undef
  * Improve here tag handling in script_output()
  * Force no quotes on hash key if match simple identifier
* Thu Oct 24 2019 okurz@suse.com
- Update to version 4.6.1571832236.5391548d:
  * Increase version numbers
  * Add new status file that worker can read from
  * Consider tests with `tools/tidy --only-changed`
  * spec: Fix missing, additional runtime requirements
  * Allow tidy to run only over local changes
  * Improve 'check_ssh_serial'
  * Make start_serial_grab blocking
  * Fix svirt backend's 100 %% CPU usage
  * codecov: Adjust to current coverage target
* Sat Oct 19 2019 okurz@suse.com
- Update to version 4.5.1571474599.7d873cb5:
  * Rely on QEMUMACHINE default in OFW
  * Update to new perltidy version 20190915
  * Allow read_json() to return multiple results
  * All JSON communication goes through myjsonrpc.pm
* Thu Oct 17 2019 okurz@suse.com
- Update to version 4.5.1571302740.fbcb3c7b:
  * Revert "Allow loading needles from current working directory" to fix regression
  * needle: Fix typo 'parrent'
  * Use $needle::needles_dir in needle downloader of developer mode
  * Log data and pool dir when running fullstack test
  * Allow loading needles from current working directory
  * Improve error handling when parsing needle JSON
  * Extend architecture.md to cover needle handling
* Tue Oct 15 2019 okurz@suse.com
- Update to version 4.5.1571127896.7bd3da32:
  * doc: Clarify implications of _SKIP_POST_FAIL_HOOKS not aborting runs
* Mon Oct 14 2019 okurz@suse.com
- Update to version 4.5.1570825562.ae51e774:
  * spec: Do not duplicate OBS-incompatible checks
  * Exclude known flaky test 13-osutils in OBS check
  * Revert "Allow loading needles from pool directory"
  * Fix broadcasting message to ws clients if there are no clients
  * command server: Improve dead-lock prevention with isotovideo
  * Fix error handling when passing message from ws client to isotovideo
  * Add possibility to have a comment text in script_run (fixed)
  * t: Fix 'Not enough arguments for EV::timer' with import ordering
  * Allow loading needles from pool directory
  * Revert "Add possibility to have a comment text in the script_run"
  * Fix tests for adding an error message to the script_run
  * Add an error message to the script_run
  * Add unit test for scheduling test modules at runtime
  * Update test_order.json if test schedule changes at runtime
  * Fix broken condition introduced by #1213
  * Handle Failed to get "write" lock on libvirt
  * Fix missing argument in consoles::sshVirtsh::run_cmd
  * Append the name of the scenario in the domain xml
  * Use hda audio instead of deprecated ac97
* Wed Sep 11 2019 okurz@suse.com
- Update to version 4.5.1568227729.687c4ca8:
  * Fix PXEBOOT once to actually check for 'once' value
  * Delete obsolete FIXME comments about sleep resolution
  * Replace diag "imperative" by "descriptive"
  * Improve result display of validate_script_output
  * Factor out click functionality from assert_and_click
  * Document needle area "click_point" in assert_and_click
  * docs: Mention devel package instead of hardcoded dependencies
  * docs: Update openSUSE repos using , priorities, better names
  * spec: Split build-, runtime and test requirements
  * Add configuration option for number of NVMe queues
  * Allow special value 'once' for PXEBOOT, to PXE boot...once
  * Fix unexpected error on xz in save_memory_dump()
  * Get rid of distracting "last frame" message from videoencoder
  * Save virsh output for later handling
  * Fix left-over qemu processes regression due to f9c71d0e
  * Fix missing data while reading from virtio_console
  * spec: Fix tests in OBS by excluding 18-backend-qemu.t
  * Add tests for backend/qemu.pm
  * Fix blank line on process output
  * Fix undefined warnings on undefined 'ARCH'
  * Fix in-package test failure on git
  * Revert "backend: DRY on check_socket method"
  * Fix "undefined"-warning in 08-autotest.t
  * spec: Add missing dependency to 'Data::Dumper'
  * Don't hardcode C++ compiler in Makefile.PL
  * Port away from the deprecated OpenCV 1 C API
  * Add automatic lookup for UEFI_PFLASH_CODE/VARS to fix UEFI on Tumbleweed machines
  * backend: DRY on check_socket method
  * Clarify that force_soft_failure is to be used from post_fail_hook
  * basetest: Fix typo in comment
  * Fix the readout of git hash as version when called from other directory
  * Make hostname in 'autoinst_url' configurable
  * Add missing 'use' for 'Data::Dumper'
  * qemu: Fix warning about undefined value in match
  * Fix unrequested wait on every type_string call (regression in cec2709f)
  * crop.py: tweak imports to work with Python 3
  * spec: Force OBS to resolve choices on opencv-devel
  * spec: Fix build for openSUSE Factory and backports after opencv4 submission
  * Replace 'serial_screen' for correct 'ssh_screen'
  * Fix missing 'consoles/serial_screen.pm' in Makefile.am
  * sshVirtshSUT use ssh aware serial screen
  * Modify workaround property to support adding reason
* Mon Jul 15 2019 okurz@suse.com
- Update to version 4.5.1563188951.f6f7c6b3:
  * spec: Provide a "devel" subpackage pulling in all build+test dependencies
  * spec: Fix warning about missing explicit perl-base
* Sat Jul  6 2019 okurz@suse.com
- Update to version 4.5.1562413838.c3d5e8ac:
  * VNC: reverse key order when sending key up events (#1174)
* Tue Jul  2 2019 okurz@suse.com
- Update to version 4.5.1562052196.bca214ee:
  * Use default graphics on x86 to circumvent "cirrus" limitations (#1169)
  * os-autoinst.spec: Fix vanished runtime requires
  * Save RPM spec file in upstream repo same as for openQA
* Wed Jun 19 2019 okurz@suse.com
- Update to version 4.5.1560860907.6a126c01:
  * t: Catch output of failing runcmd
  * osutils: Let the "attempts" sound less harmful
  * t: Do not waste time waiting in test 13-osutils.t
  * t: Fix all uncaught output and warnings in 08-autotest.t
  * t: Fix warning about undefined variable in 17-basetest.t
  * sshVirtsh: Remove procedure add_serial_console()
* Sun Jun 16 2019 okurz@suse.com
- Update to version 4.5.1560548250.151bd110:
  * Use QUIET variable for script_run/output
* Fri Jun 14 2019 okurz@suse.com
- Update to version 4.5.1560502370.2654e4ef:
  * Format using Perl::Tidy 20190601
* Wed Jun  5 2019 okurz@suse.com
- Update to version 4.5.1559738889.52a75c17:
  * sshVirtsh: Log libvirt xml files
  * Fix missing or double output in autoinst-log.txt with partial revert
  * Increment API version after  'Always log to autoinst-log.txt'
  * Fix perl warning about undefined VIRTIO_CONSOLE
  * Fix typo in HDDFORMAT die handler
  * Always log to autoinst-log.txt
  * Add recursive get data call
* Wed May 29 2019 okurz@suse.com
- Update to version 4.5.1559044089.b8a76372:
  * qemu: Multiple virtio-consoles
  * Allow failing for matching regex in autoinst log
* Mon May 27 2019 okurz@suse.com
- Update to version 4.5.1558854356.09e08ded:
  * Log best candidate needle also on timeout
* Fri May 24 2019 okurz@suse.com
- Update to version 4.5.1558691185.f7da5cd0:
  * Avoid "unitialized value in string eq" warning
  * Add quiet option to wait_serial()
* Tue May 21 2019 okurz@suse.com
- Update to version 4.5.1558432600.6c62e09d:
  * Don't modify backend vars when running test
* Wed May 15 2019 okurz@suse.com
- Update to version 4.5.1557827957.ce72694e:
  * Add debug output before 'flushing frames'
* Mon May 13 2019 okurz@suse.com
- Update to version 4.5.1557391016.927f3d85:
  * Add explanation to error regarding command server
  * Extend type_password arguments
  * Add an option of mousehide for assert_and_click
  * Assign click_point when parsing needle
  * Take click point from area over to match
  * Enable assert_and_click to use an area's click point
  * Remove out-commented code in assert_and_click
  * script_output: log script for execution into log
  * Make get_var_array return values consistent
* Wed Apr 17 2019 okurz@suse.com
- Update to version 4.5.1555336742.ebf62298:
  * Export hotkey to os-autoinst-distri
* Thu Apr 11 2019 okurz@suse.com
- Update to version 4.5.1554982352.0cb8a1e0:
  * Fix assert_screen_change method call
  * Allow multiple tap interfaces in one network
  * Fix error message in consoles::network_console
  * consoles: Rename virtio_screen to serial_screen
  * svirt: scp serial_terminal.txt log to worker
  * svirt: Refactor serial console initialization and running code
  * svirt: Rename $command variable back to $cmd
  * sshVirtsh: Rename $channel variable to $chan
  * svirt: Merge get_ssh_output() implementations into single one
  * svirt: Remove unused variables from start_serial_grab()
  * svirt: Pass credentials via %%hash in run_ssh_cmd()
  * svirt: Fix virsh console initialization
  * svirt: Fix serial backend for s390x
  * consoles/sshVirtshSUT: Fix domain detection
* Fri Mar 29 2019 okurz@suse.com
- Update to version 4.5.1553864471.599444e3:
  * Use always $bmwqemu::vars{NEEDLES_DIR} directly
  * Make failing exec in sshIucvconn non-fatal
  * Update to handle xz compressed images
  * Improve error messages for VNC connection
  * Improve error handling when using Net::SSH2 library
  * Use blessed fake baseclass object appropriately
  * Prevent rendering empty results if no image available
  * Move virtio rng option _after_ Ethernet setup to keep it as eth0
  * VMware: Retrieve console-only variable
  * VMware: Delay boot by 10 seconds
* Tue Mar 12 2019 okurz@suse.com
- Update to version 4.5.1552382335.1080c396:
  * Use Mojo helper to write result files
  * Add QEMU_HUGE_PAGES_PATH test
  * Add support for TIMEOUT_SCALE in wait_screen_change
  * Fix scale_timeout call in wait_idle
  * Add QEMU_HUGE_PAGES_PATH option
  * Prevent recording empty soft failure test detail
* Tue Mar 12 2019 Petr Vorel <pvorel@suse.cz>
- Add dependency for IO::Scalar (needed for
  https://github.com/os-autoinst/os-autoinst/pull/1109)
- Add url to github to fix "W: no-url-tag" warning
* Tue Mar  5 2019 okurz@suse.com
- Update to version 4.5.1551793347.0db294cd:
  * Improve feedback on "half-open socket"
  * tidy: Replace bashism and change shebang to /bin/sh
  * tidy: Replace bashism with dirname + doc
* Fri Mar  1 2019 okurz@suse.com
- Update to version 4.5.1551452505.a5d8b452:
  * Add test for logging to t/Makefile.am
  * doc: Add section Development on Debian/Ubuntu
  * Extract common run_cmd to prevent duplication
  * Rename svirt method run_cmd to prevent confusion
  * Let assert and check_screen fails if no tags specified
  * Remove MULTINET variable and update documentation
  * Ensure SCHEDULE to load modules on existing vars.json
* Tue Feb 26 2019 okurz@suse.com
- Update to version 4.5.1551191805.807aed16:
  * Run tidy on the correct directory
* Sat Feb 23 2019 okurz@suse.com
- Update to version 4.5.1550925474.8f5465e5:
  * Extend arguments for type_string
  * Configure bootindex for first path only
  * Add all tests to t/Makefile.am
* Tue Feb 19 2019 okurz@suse.com
- Update to version 4.5.1550607545.b7b33fb7:
  * tests: Run also 22-svirt.t
  * tidy: Fix path detection for os-autoinst-distri-opensuse
  * Fix skipping needles with missing PNGs and add a test
  * Fix memory leak when failing to read image
* Sun Feb 17 2019 okurz@suse.com
- Update to version 4.5.1550400351.e380fdd7:
  * Enhance documentation for testapi::waitserial()
* Fri Feb 15 2019 okurz@suse.com
- Update to version 4.5.1550146791.307c430d:
  * Provide default for get_var('VMWARE_REMOTE_VMM')
  * Add workaround for snapshots on VMware
  * Provide default for $vmware_datastore definition
  * Enable snapshots on VMware
* Tue Feb 12 2019 okurz@suse.com
- Update to version 4.5.1549897848.e764de36:
  * Silence complain about undefined $libvirt_connector
* Sun Feb 10 2019 okurz@suse.com
- Update to version 4.5.1549618330.a27d1d27:
  * Allow relative paths in PRODUCTDIR as well
  * Fix table documenting svirt backend variables
  * Improve code for announcing test end to ws clients
  * Remove comment referring to non-existent web page
  * Prevent error about cmd srv connection when test ends
  * VMware: disable snapshots
* Mon Feb  4 2019 okurz@suse.com
- Update to version 4.5.1549290558.3e4a5c07:
  * doc: Add PAUSE_AT et al.
* Thu Jan 31 2019 okurz@suse.com
- Update to version 4.5.1548936913.ed3a07cd:
  * Install sshVirtshSUT.pm
  * Test processing of 'set_pause_at_test' command
  * Prevent warning in command handler
  * Check for correct tidy version on execution
* Mon Jan 21 2019 okurz@suse.com
- Update to version 4.5.1548066416.34c49266:
  * openvswitch: check dot1q-tunnel support
* Wed Jan 16 2019 okurz@suse.com
- Update to version 4.5.1547655571.a1a10bd6:
  * openvswitch: change vlan_mode to dot1q-tunnel
  * qemu: use /dev/urandom as source for virtio RNG
  * Add "error" value to matches
* Thu Jan 10 2019 okurz@suse.com
- Update to version 4.5.1547114685.2ba023eb:
  * Add missing network_console.pm to Makefile
  * Add support to checkout git repos+refspecs
  * Do not incomplete on connection error with ssh based consoles
* Fri Jan  4 2019 okurz@suse.com
- Update to version 4.5.1546602946.a7be7efa:
  * Fix missing linebreak in die_handler debug output
* Sat Dec 22 2018 okurz@suse.com
- Update to version 4.5.1545369866.fc084a6a:
  * IPMI: support mc reset for sol stability
  * Fix "tidy" use within os-autoinst-distri-opensuse
  * Makefile: Prevent docker "build" and "run" to run in parallel
* Thu Dec 20 2018 okurz@suse.com
- Update to version 4.5.1545236486.6ef6a533:
  * Introduce versioning for the developer mode API
  * Use one variable for pausing on screen mismatch
  * Extend command processing tests
  * Allow to pause on next command
  * Disable pause on check_screen timeout when disabling for assert_screen
  * Reformat with latest version of perltidy
* Thu Dec 13 2018 okurz@suse.com
- Update to version 4.5.1544691921.44e93d8d:
  * Don't write _SECRET_* vars in vars.json
* Mon Dec 10 2018 okurz@suse.com
- Update to version 4.5.1544434670.99778697:
  * doc: Add missing ;
* Fri Dec  7 2018 Stephan Kulow <coolo@suse.com>
- add Cpanel::JSON::XS as buildrequire
* Fri Dec  7 2018 okurz@suse.com
- Update to version 4.5.1544111663.31867f0e:
  * Replace all uses of JSON and JSON::XS with Mojo::JSON and Cpanel::JSON::XS
  * Clean up generically named variables and use more fitting names
  * Make get_cmd_output() use other connections than 'ssh'
  * Describe VMWARE_NFS_DATASTORE & VMWARE_REMOTE_VMM
  * VMware: Rewrite add_disk()
  * VMware: Replace vCenter with ESXi host
  * VMware: Support snapshots, suspend, resume etc
  * Use Perl::Critic::Freenode to determine good coding style
  * Add unit test for format_vtt_timestamp
* Fri Nov 30 2018 okurz@suse.com
- Update to version 4.5.1543593014.1e83b015:
  * Include folder hierachy in category name
  * Remove actual use of bmwqemu from command processing tests
  * Increase timeout in fullstack test for 'Skip timeout'
  * Test command processing for assert/check screen and setting timeout
  * Allow to adjust timeout via command server
  * test: Add QEMU_APPEND option tests
  * Make currently executed function available to developer mode
  * Keep only the 30 most recently used needle images
  * qemu: Enhance QEMU_APPEND option to handle multiple options with or without params
* Fri Nov 30 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable t/18-qemu-options.t in %%check as done for t/99-full-stack.t
  as it requires qemu
* Mon Nov 26 2018 okurz@suse.com
- Update to version 4.5.1542781566.58d02775:
  * Correct HDDMODEL / CDMODEL deprecation message (#1064)
  * Prevent cmd srv being busy in loop consuming isotovideo messages
  * Set script when using extra test results (#1031)
  * qemu: Handle files compressed as *.xz (#1055)
  * Move architecture.md to doc subdirectory (#1054)
  * qemu: Add QEMU_APPEND option (#1051)
  * Add option to override status of test modules with soft-fail (#1052)
  * Add missing Test::Mojo dependency (#1056)
  * Remove extra leading zero from log timestamps (#1053)
  * svirt/Xen: Expect the image to be located on the svirt host (#1050)
  * [sshXtermIPMI] refactor reset function for ipmi console (#1021)
  * Needle editor - show all key bindings (#1049)
  * Test initialization of svirt backend
  * Add documentation about svirt backend
  * svirt backend: Add serial console for SUT
  * qemu: virtio terminal is enabled by default
  * Allow adding additional serial port when using svirt backend
  * Prevent adding empty passwd-attribute to domain XML
  * svirt: Allow to use a different user than root
  * Prevent record_testresult to override failed with softfailed
  * Avoid misleading stacktrace when backend dies (#1033)
  * Don't attach screenshot when recording softfailure (#1042)
  * Check whether result with tags is added on timeout
  * Record additional failing match only if configured to pause on timeout
  * Upload full mismatch when paused on assert_screen timeout
  * Allow freeze_vm to be called outside post_fail_hooks (#1043)
  * Improve 'WARNING: check_asserted_screen took ...'
  * Remove zkvm authentication code
  * Ensure main.pm is still used for proper initialization on SCHEDULE (#1039)
  * Add test flag to revert to last good when test module didn't fail (#1034)
  * Remove MATCH(...) debug output
  * Disable stopwatch debug output
  * Record info for barriers and mutexes (#978)
  * Avoid overriding SERIALDEV obtained from testsuite or machine settings (#1037)
  * Fix undefined BACKEND warning in search_for_expected_serial_failures
  * Use Test::Warnings where possible to prevent warnings in tests
  * Improve error handling in needle download
  * Handle OPENQA_URL set to eg. 'localhost:9526' correctly
  * Download new needles on resume in autotest
  * Add limit for downloading new needles
  * Improve deducing openQA URL for needle downlaod from test variables
  * Refactor needle download and add unit tests
  * Download new needles from openQA on resume
  * Delete redundant newlines in die's
  * Prevent warnings in 02-test_ocr.t
  * Fix perlcritic error in backend/driver.pm
  * Add doc for OFW
  * Block and ignore SIGTERM from opencv threads
  * Reduce the opencv libraries we link to
  * testapi: Relax regex in script_output filtering what to return
* Wed Sep 26 2018 okurz@suse.com
- Update to version 4.5.1537682748.0d10ddb9:
  * Treat $OpenQA::Isotovideo::Interface::version as test API (#1023)
  * Fix led state change with tigervnc (#1028)
  * script_output: increase logging in case of failure (#1025)
  * Unit test for script_output
  * Use wait_serial to wait for here tag end
  * Use here tag in script_out
  * Add option to always dump memory after a test failure
  * qemu: Add knobs and dials for tuning snapshotting
  * Prefer override test module files if found in the openQA "other" repo path
  * isotovideo: Require explicit 'tests/' prefix within SCHEDULE again for openQA use
  * Add variable SCHEDULE to define the full schedule by variable
  * t: Fix failures in 99-full-stack.t depending on system performance
  * testapi: Fix spellcheck with whitelisted 'kvm', 'VM'
  * t: Fix perl warning "Possible attempt to separate words with commas"
  * Fix "Use of uninitialized value $_[0] in join or string" in 'diag'
  * Die when remote backend programs are missing (#1024)
* Thu Sep 13 2018 okurz@suse.com
- Update to version 4.5.1536750184.92e52b69:
  * command server: Don't mix myjsonrpc with Mojo::IOLoop::Stream
  * Improve log messages and error handling in web socket server
* Fri Sep  7 2018 okurz@suse.com
- Update to version 4.5.1536326847.7ce7ffba:
  * qemu: log that state file is being saved (#1017)
  * Add unit tests for commands related to pausing on timeout
  * Refactor command processing in isotovideo
  * Allow to pause on check_screen timeout
* Tue Aug 21 2018 okurz@suse.com
- Update to version 4.5.1534865613.ff83b57d:
  * Properly log messages from the backend
  * Replace call to autotest::selected_console
  * Add current_console method
  * Prevent double timestamps on QEMU command line log entry
  * Adjust tests to the changes of serial failures detection
  * Add fatal serial failure type to stop execution if detected
  * Override test results if hard serial failure detected
  * docker: attempt to upgrade packages before run
  * docker: allow to install modules with cpan with INSTALL_FROM_CPAN=1
  * osutils: No need internal pipes here
  * Add log output for sim level in wait_still_screen
  * Add unit tests for check and assert shutdown
  * Introduce check_shutdown for testapi
* Wed Aug  8 2018 okurz@suse.com
- Update to version 4.5.1533739786.546c7c63:
  * qemu: Allow user to set HDD serial number
  * Add unit test for serial output parsing
  * Add messages to serial failures
  * Improve keys sent when expecting needle (#982)
  * amt: initial commit (#983)
  * Increase isotovideo interface version
  * Use diag instead of print in isotovideo
  * Adjust test for fullstack test to test pause on assert_screen timeout
  * Test pause on assert_screen/check_screen timeout
  * Fix typo occured -> occurred
  * Pause only on assert_screen failure
  * Don't pass unused paremeter to _check_backend_response
  * Send full test name on 'set_current_test' command
  * Propagate reason for pause
  * Take a screenshot on assert_screen timeout
  * Block autotest on timeout if flag is set in isotovideo
  * Add flag to isotovideo whether to pause on assert screen failure
  * osutils: Avoid racing to get output
  * virtio_terminal: Avoid connecting to already connected socket
  * Move informative message to use bwmqemu::diag
  * Cleanup osutils runcmd functions and avoid code duplication
  * Build process object lazily
  * Add Mojo::IOLoop::ReadWriteProcess to cpanfile deps
  * osutils: change runcmd logic
  * Move driver pipes to channels
  * Move qemu process to EventEmitter model
  * Avoid enabling unused consoles after reverting to a snapshot
  * Revert "Create dummy pflash vars file to avoid asset caching failure" (#1004)
  * Avoid resetting all consoles while reverting to a snapshot
  * Avoid performing multiple or unnecessary console resets after revert
  * qemu: Prevent serial logs from being truncated on revert
  * Remove default floppy drive
  * Create dummy pflash vars file to avoid asset caching failure
  * Use bootindex with non-uefi systems
  * Avoid rolling back to undefined console
  * Avoid conflicting block device options
  * Revert "Add label message to serial failures"
  * Reduce verbosity of command server
  * Fixup broken indentation
  * Bump isotovideo interface version
  * Extend qemu tests
  * Wait for post migrate state after migration
  * The Great QEMU Rewrite of 2018
  * Prevent perl tidy from completely ruining well formatted code
  * s390x: Fix typo in diag message
  * Test web socket route of command server
  * Use Test::Mojo to test command server
  * Add label message to serial failures
  * testapi: Adapt check_screen timeout default to proposal in documentation
* Mon Aug  6 2018 edigiacinto@suse.com
- Add dependency perl(Mojo::IOLoop::ReadWriteProcess)
* Wed Aug  1 2018 marius.kittler@suse.com
- Add dependency perl(Test::Exception)
  Required for https://github.com/os-autoinst/os-autoinst/pull/993
* Tue Jul 10 2018 okurz@suse.com
- Update to version 4.5.1530875209.f6cd7968:
  * Add backend/spvm.pm to Makefile.am
  * Introduce a slim pvm backend using ssh
  * Add a note for script_output method when is not using dedicated serial
  * Fix repository path from codecov reports
  * Move to codecov
  * Use the docker image we use in openQA for os-autoinst
  * Run tests inside docker to normalise testing environment
* Tue Jul 10 2018 okurz@suse.com
- Replace deprecated tar_scm service by obs_scm
* Mon Jun 18 2018 okurz@suse.com
- Update to version 4.5.1529342275.852c3ff6:
  * Add state of the test_execution and name of the test name to pause at (#976)
  * Document the multi-process architecture (#975)
  * tidy: exclude .git/ from search path (#974)
  * Make ssh failures to remote systems debuggable (#973)
  * Wait for command typed in serial terminal before running it (#971)
  * Add INCLUDE_MODULES to only schedule whitelisted modules on request (#962)
  * Allow where parameter for mutex unlocking (#969)
  * Install OpenQA/Commands.pm (#972)
  * ppmclibs/tinycv_impl.cc code improvements (#968)
  * Rename variables in isotovideo
  * Improve debug info, fix tests
  * Allow to pause test execution at specific test
  * Get rid of the developer route again
  * Disable timeout on the stream to the parent
  * Broadcast debugging aids to web clients
  * Avoid one more global variable
  * Open a websocket server in isotovideo to reply commands
  * Remove old interactive mode
* Sun May 27 2018 okurz@suse.com
- Update to version 4.5.1527308405.8b586d5e:
  * DRY on xterm call (#963)
  * Correct return values for match_has_tag (#967)
* Sun May 27 2018 coolo@suse.com
- remove require on withlock
- downgrade require on tesseract to recommend (not really
  required for base functionality)
* Thu May 17 2018 okurz@suse.com
- Update to version 4.5.1526456062.30f96887:
  * Bump interface version to changes introduced by  1a0381b
* Wed May  9 2018 okurz@suse.com
- Update to version 4.5.1525874912.1dc03895:
  * localXvnc: Output the PIDs of the involved processes (#961)
  * Add mutex_wait wrapper to lockapi
* Fri May  4 2018 okurz@suse.com
- Update to version 4.5.1525413876.6c59528a:
  * Allow environment variable to point to OPENQA_LIBPATH (#959)
  * isotovideo: Add support to forward command line parameters as test settings (#950)
  * testapi: Output all arguments in log_call (#957)
* Thu Apr 26 2018 okurz@suse.com
- Update to version 4.5.1524736170.cc9d9ff2:
  * Add proceed_on_failure option (#954)
  * svirt KVM: Set <on_reboot> to 'destroy' (#956)
  * Set distribution earlier in isotovideo (#955)
  * mention TIMEOUT_SCALE in dock/backend_vars.asciidoc (#951)
  * testapi: Correct comment references to exception 'FailedNeedle'
  * Fix missing text thumbnail after needle related test failures
  * Do not quote -append qemu parameter
* Mon Apr 23 2018 okurz@suse.com
- Update to version 4.5.1524160420.7b402a0a:
  * testapi: Improve documentation for "wait_screen_change" (#943)
* Thu Apr 19 2018 okurz@suse.com
- Update to version 4.5.1523984252.2f46f2e2:
  * Bump testapi version as per change to select_console (#946)
  * Allow passing parameters to activate_console method (#945)
* Mon Apr  9 2018 okurz@suse.com
- Update to version 4.5.1523276311.2588e578:
  * Update current test module details when cancelling running job (#941)
  * Add OFFLINE_SUT mode to QEMU backend (#940)
  * Prints the isotovideo version and interface number
  * Merge qemu output failure conditions (#936)
  * Add test option _SKIP_POST_FAIL_HOOKS to save time on test development (#938)
  * Remove specific qemu code (#934)
  * Add username parameter for sshCommand
  * Allow setting console tty and other args (#933)
  * Move code from autotest to basetest
  * Add message to the invocation of the die function
  * Cleverness is not maintanable
  * Search for patterns in the SERIAL file and raise failures
* Tue Mar  6 2018 okurz@suse.com
- Update to version 4.5.1520265920.6728b435:
  * Tries to guess which qemu executable should use via WORKER_CLASS (#931)
  * Remove support for backend.crashed file (#930)
  * qemu: enable discard support for disks
  * Add support to override HDDMODEL per disk (#928)
* Sat Mar  3 2018 okurz@suse.com
- Update to version 4.5.1519457089.09762e3e:
  * testapi: Refactor script_output into distribution.pm and fix race (#926)
  * Use a fixed version of perltidy (#927)
  * Avoid broken perltidy in cpanfile
* Sat Feb 17 2018 okurz@suse.com
- Update to version 4.5.1518780731.3ca7dc34:
  * Do not fail on chattr failures (#924)
  * qemu: disable CoW for the HDD image directory (#790)
  * get_ssh_output and get_cmd_output return array in list context (#916)
  * Avoid letting the kids get loose. (#919)
  * Don't add floppy for arm/aarch (#923)
  * wip -- test to prevent double typing echo on virtio-console
  * Correct VNC stall threshold variable name (#922)
  * Check runcmd return status (#898)
  * testapi: Correct spelling mistake
  * testapi: Ensure script_output only returns the actual ouput of the executed script
  * tinycv: Add test for send_with_fd
  * testapi: Allow memory dump any time
  * qemu: Increase memory dump performance
  * tinycv: Add send_with_fd utility function
* Mon Jan 29 2018 okurz@suse.com
- Update to version 4.5.1516891126.e9d61c6d:
  * qemu: Die unless mandatory variable WORKER_HOSTNAME is set in NBF (#914)
  * Extract function which will retrun VM's host IP (#913)
* Tue Jan 23 2018 okurz@suse.com
- Update to version 4.5.1516628925.5467a37f:
  * Add single quote if parameter contains whitespace (#911)
  * Remove commented code (#912)
* Sat Jan 20 2018 okurz@suse.com
- Update to version 4.5.1516396050.1f10a0db:
  * Try to load OpenQA::Parser if present and parse extra test files. Add also support for xUnit and LTP
* Tue Jan 16 2018 okurz@suse.com
- Update to version 4.5.1516095934.1b1283ad:
  * Move and increase sleep time between ipmi power actions
  * Add variable to define stall treshold
  * Add variable to don't power of the machine after test
  * Increase the limits for checking the VNC console. (#906)
  * Makefile.am: Fix install directory for RunArgs.pm (#907)
* Sat Jan 13 2018 okurz@suse.com
- Update to version 4.5.1515766826.5f24243a:
  * Limit the execution time for save_memory_dump
  * Update documentation for save_storage_drives
  * Memory dumps are only callable from post_fail-hook
  * Add RunArgs to the Makefile
  * Display interface version when using --version
  * fix use of initialized value
* Tue Jan  9 2018 okurz@suse.com
- Update to version 4.5.1515414371.04e17fdf:
  * Ignore WORKER_HOSTNAME for qemu explicitly (#903)
  * Polling the read socket in the capture loop (#902)
* Fri Dec 22 2017 okurz@suse.com
- Update to version 4.5.1513942030.1c7bb3f5:
  * Do not reset NUMDISKS if RAIDLEVEL is not present (#901)
  * svirt: Add {start,stop}_serial_grab interface (#899)
  * Retidy - perltidy 20171214 changed output (#896)
  * Simply ignore '\r' in type string (#894)
  * Change the logs timestamp to ISO8601. (#893)
  * Add method to get files content and integration test
  * Add possibility to share files on worker directly
  * Add RunArgs to loadtest (#887)
  * Remove empty miniatures. (#891)
  * Fix error checking on load_snapshot and remove sleep (#890)
  * Drop all hmp commands and use qmp exclusively
  * [POC] Wrap HMP commands with QMP's human-monitor-command
  * Distinguish modules name in a test run if it's a duplicate (#884)
* Fri Dec 15 2017 coolo@suse.com
- disable perltidy and perlcritic checks during build
* Tue Nov 28 2017 okurz@suse.com
- Update to version 4.5.1511858414.576c33f6:
  * Fix quoting bug in type_command support (#886)
  * Extend lockapi barrier_wait to accept also parameters, and add support to check_dead_job (#880)
* Mon Nov 27 2017 okurz@suse.com
- Update to version 4.5.1511530266.fe4b1c52:
  * Fix snd2png check on TW: don't use PNM but PNG (#885)
  * Fix test failures on Tumbleweed (#883)
  * add debian ovmf to locations array
  * Add offline mode for script_output
  * Xen: Support multiple HDDs
  * svirt: Set NUMDISKS=4 when RAIDLEVEL is defined
  * Replacement of hot filehandlers for Mojo::Log (#876)
* Mon Nov 27 2017 coolo@suse.com
- bump to 4.5 to be in sync with openQA
* Thu Nov  2 2017 okurz@suse.com
- Update to version 4.4.1508936943.39adc5eb:
  * Fix scale_timeout call in wait_serial function
  * sshVirtsh: Hide confusing errors about undefined machines (#866)
  * avoid accidentally cleaning (#865)
  * Generalize x11_start_program with standard array argument (#863)
  * Remove unused reload_needles property in backend
  * Allow set_var to reevaluate needles
  * Add option to exit early for test schedule evaluation (#853)
  * Prevent diag message about _EXIT_AFTER_SCHEDULE if not requested
  * Make sure select_console on broken vnc fails (#872)
  * Introduce check_recorded_sound method (#873)
* Wed Sep 20 2017 coolo@suse.com
- add Test::Mock::Time require
* Wed Sep 20 2017 okurz@suse.com
- Update to version 4.4.1505909574.e0b4d014:
  * Correct validate_script_output test to actually test something
  * Add test for wait_still_screen
  * testapi: Add 'no_wait' option to wait_still_screen
  * Fix warning in test about 'prototype mismatch'
  * Allow type_string to wait_still_screen
  * Use hash ref in query_isotovideo
  * Add test for wait_idle in full stack test.
  * consoles: s3270: Make debug output of queue content less noisy
  * Update API document referring function type_string
  * Remove typing tests from integration tests (#857)
* Sat Jun 17 2017 stefan.bruens@rwth-aachen.de
- Add dependency on matching perl version, as the tinycv module is
  installed in a version dependent path
- Drop bogus conditionals, suse_version <= 132 will never match
* Thu Mar 23 2017 santiago.zarate@suse.com
- Inline replacement for version parameter on isotovideo
* Sun Mar 12 2017 oholecek@suse.com
- new perl(Test::Warnings) dependency
* Wed Sep  7 2016 oholecek@suse.com
- new perl(Devel::Cover) dependency
- package os-autoinst/tools/check_coverage tool
* Sat Jul  9 2016 coolo@suse.com
- update base version to 4.4 to express the new isotovideo API
  towards the worker
* Mon May 30 2016 oholecek@suse.com
- new perl(Test::MockModule) dependency
* Mon Feb 15 2016 oholecek@suse.com
- new perl(Test::Output) dependency
* Thu Jan 14 2016 oholecek@suse.com
- update base version to 4.3
* Tue Dec  8 2015 coolo@suse.com
- add snd2png
* Fri Nov 27 2015 coolo@suse.com
- new dependencies
* Tue Nov 24 2015 coolo@suse.com
- disable perlcritic outside of Factory - too useless to test with
  old perlcritic versions
* Tue Nov 24 2015 coolo@suse.com
- adapt file list
* Tue Nov 17 2015 coolo@suse.com
- remove gone files from file list
* Tue Aug 25 2015 lnussel@suse.de
- require tesseract-ocr on >= 13.2
* Thu Jul  9 2015 nadvornik@suse.com
- created os-autoinst-openvswitch subpackage
* Tue Mar 10 2015 oholecek@suse.com
- add mmapi.pm
* Sun Mar  1 2015 oholecek@suse.com
- add lockapi.pm
* Thu Feb 19 2015 lnussel@suse.de
- remove fetchneedles call. now in openQA
* Wed Jan 28 2015 coolo@suse.com
- make it version 4
* Thu Nov 27 2014 coolo@suse.com
- add videoencoder
* Thu Nov 27 2014 coolo@suse.com
- add distribution.pm
* Tue Nov 25 2014 coolo@suse.com
- recommend multimon too
* Tue Nov 25 2014 coolo@suse.com
- add testapi.pm to the file list
* Mon Nov 24 2014 coolo@suse.com
- recommend eatmydata for performance
* Mon Aug 18 2014 lnussel@suse.de
- adjust filelist for removed files
* Mon Jul 28 2014 lnussel@suse.de
- require qemu >= 2.0.0
* Tue Jul  8 2014 lnussel@suse.de
- include VNC.pm in file list
- add Crypt::DES to deps
* Tue Apr  8 2014 coolo@suse.com
- remove tidy script
* Tue Mar 25 2014 lnussel@suse.de
- remove rpc.pl from file list
* Wed Mar 12 2014 coolo@suse.com
- require qemu-img, quite useful :)
* Wed Mar 12 2014 coolo@suse.com
- switch github url to os-autoinst orga
* Mon Mar 10 2014 tchvatal@suse.com
- Use devel dep over pkgconfig one to build with 11.4 opencv
* Mon Mar 10 2014 tchvatal@suse.com
- Cleanup with spec-cleaner and use requires(pre)
* Tue May 14 2013 lnussel@suse.de
- initial package
